@@ -5,8 +5,6 @@ from .slash.types import MessageCommand, SlashCommand, SlashSubcommand, UserComm
 import discord
 from discord.errors import InvalidArgument
 from discord.ext.commands import errors
-from discord.ext.commands._types import Error, Hook
-from discord.ext.commands.core import ErrorT, HookT
 from discord.ext.commands.cooldowns import BucketType, CooldownMapping
 
 import asyncio
@@ -50,7 +48,7 @@ class BaseCallable():
         if hasattr(self.callback, "__commands_max_concurrency__"):
             self._max_concurrency = self.callback.__commands_max_concurrency__
 
-        self._before_invoke: Optional[Hook] = None
+        self._before_invoke = None
         try:
             before_invoke = self.callback.__before_invoke__
         except AttributeError:
@@ -58,7 +56,7 @@ class BaseCallable():
         else:
             self.before_invoke(before_invoke)
 
-        self._after_invoke: Optional[Hook] = None
+        self._after_invoke = None
         try:
             after_invoke = self.callback.__after_invoke__
         except AttributeError:
@@ -176,7 +174,7 @@ class BaseCallable():
             return bucket.get_retry_after(current)
 
         return 0.0
-    def error(self, coro: ErrorT) -> ErrorT:
+    def error(self, coro):
         """A decorator that registers a coroutine as a local error handler.
 
         A local error handler is an :func:`.on_command_error` event limited to
@@ -197,7 +195,7 @@ class BaseCallable():
         if not asyncio.iscoroutinefunction(coro):
             raise TypeError('The error handler must be a coroutine.')
 
-        self.on_error: Error = coro
+        self.on_error = coro
         return coro
     def has_error_handler(self) -> bool:
         """:class:`bool`: Checks whether the command has an error handler registered.
@@ -205,7 +203,7 @@ class BaseCallable():
         .. versionadded:: 1.7
         """
         return hasattr(self, 'on_error')
-    def before_invoke(self, coro: HookT) -> HookT:
+    def before_invoke(self, coro):
         """A decorator that registers a coroutine as a pre-invoke function.
 
         This function is called directly before the command is
@@ -230,7 +228,7 @@ class BaseCallable():
 
         self._before_invoke = coro
         return coro
-    def after_invoke(self, coro: HookT) -> HookT:
+    def after_invoke(self, coro):
         """A decorator that registers a coroutine as a post-invoke function.
 
         A post-invoke function is called directly after the command is
@@ -309,6 +307,7 @@ def slash_cog(name=MISSING, description=MISSING, options=[], guild_ids=MISSING,
     ----------
         name: :class:`str`, optional
             1-32 characters long name; default MISSING
+
             .. note::
 
                 The name will be corrected automaticaly (spaces will be replaced with "-" and the name will be lowercased)
@@ -373,6 +372,7 @@ def subslash_cog(base_names, name=MISSING, description=MISSING, options=[], guil
                 If you want to make a subcommand (``/base name``), you have to use a str instead of a list
         name: :class:`str`, optional
             1-32 characters long name; default MISSING
+            
             .. note::
 
                 The name will be corrected automaticaly (spaces will be replaced with "-" and the name will be lowercased)
@@ -396,7 +396,6 @@ def subslash_cog(base_names, name=MISSING, description=MISSING, options=[], guil
 
     Decorator
     ---------
-
         callback: :class:`method(ctx)`
             The asynchron function that will be called if the command was used
                 ctx: :class:`~SlashedSubCommand`
@@ -407,8 +406,7 @@ def subslash_cog(base_names, name=MISSING, description=MISSING, options=[], guil
                     ``ctx`` is just an example name, you can use whatever you want for that
     
     Example
-    -------
-    
+    --------
     subcommand
 
     .. code-block::
@@ -467,6 +465,7 @@ def context_cog(type: Literal["user", 2, "message", 3], name=MISSING, guild_ids=
                         The used slash command
                     message: :class:`~Message`
                         The message on which the command was used
+                    
                     .. note::
 
                         ``ctx`` and ``message`` are just example names, you can use whatever you want for that
@@ -539,4 +538,4 @@ def listening_component_cog(custom_id, messages=MISSING, users=MISSING, componen
     """
     def wraper(callback):
         return ListeningComponent(callback, messages, users, component_type, check, custom_id)
-    return wraper
\ No newline at end of file
+    return wraper
